==> posixtestsuite_1.5.1.orig.tar.gz: posixtestsuite/conformance/interfaces/aio_read/3-2.c <==
/*
 * Copyright (c) 2004, Bull SA. All rights reserved.
 * Created by:  Laurent.Vivier@bull.net
 * This file is licensed under the GPL license.  For the full content
 * of this license, see the COPYING file at the top level of this 
 * source tree.
 */

/*
 * assertion:
 *
 * aiocbp may be be used as an argument to aio_error() and aio_return().
 *
 * method: (short read)
 *
 *	- write data to a file
 *	- read file using aio_read
 *	- check error and return codes using previous aiocb
 */

#define _XOPEN_SOURCE 600
#include <stdio.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
#include <aio.h>

#include "posixtest.h"

#define TNAME "aio_read/3-2.c"

int main()
{
	char tmpfname[256];
#define BUF_SIZE 1024
	char buf[BUF_SIZE];
	int fd;
	struct aiocb aiocb;

#if _POSIX_ASYNCHRONOUS_IO != 200112L
	exit(PTS_UNSUPPORTED);
#endif

	snprintf(tmpfname, sizeof(tmpfname), "/tmp/pts_aio_read_3_2_%d", 
		  getpid());
	unlink(tmpfname);
	fd = open(tmpfname, O_CREAT | O_RDWR | O_EXCL,
		  S_IRUSR | S_IWUSR);
	if (fd == -1)
	{
		printf(TNAME " Error at open(): %s\n",
		       strerror(errno));
		exit(PTS_UNRESOLVED);
	}

	unlink(tmpfname);

	if (write(fd, buf, BUF_SIZE/2) != BUF_SIZE/2)
	{
		printf(TNAME " Error at write(): %s\n",
		       strerror(errno));
		exit(PTS_UNRESOLVED);
	}

	/* try to read BUF_SIZE bytes whereas the file is BUF_SIZE/2 long */

	memset(&aiocb, 0, sizeof(struct aiocb));
	aiocb.aio_fildes = fd;
	aiocb.aio_buf = buf;
	aiocb.aio_nbytes = BUF_SIZE;

	if (aio_read(&aiocb) == -1)
	{
		printf(TNAME " Error at aio_read(): %s\n",
		       strerror(errno));
		exit(PTS_FAIL);
	}

	/* Wait for request completion */
	while (aio_error(&aiocb) == EINPROGRESS);

	/* error status shall be 0 and return status shall be BUF_SIZE/2 */

	while (aio_error(&aiocb) == EINPROGRESS);

	if (aio_error(&aiocb) != 0)
	{
		printf(TNAME " Error at aio_error()\n");
		exit(PTS_FAIL);
	}

	if (aio_return(&aiocb) != BUF_SIZE/2)
	{
		printf(TNAME " Error at aio_return()\n");
		exit(PTS_FAIL);
	}

	close(fd);
	printf ("Test PASSED\n");
	return PTS_PASS;
}

==> posixtestsuite_1.5.2.orig.tar.gz: posixtestsuite/conformance/interfaces/aio_read/11-2.c <==
/*
 * Copyright (c) 2004, Bull SA. All rights reserved.
 * Created by:  Laurent.Vivier@bull.net
 * This file is licensed under the GPL license.  For the full content
 * of this license, see the COPYING file at the top level of this 
 * source tree.
 */

/*
 * assertion:
 *
 * aio_read() shall fail with [EINVAL] or the error status of the operation
 * shall be [EINVAL] if aio_offset would be invalid, or aio_reqprio is not a valid
 * value, or aio_nbytes is an invalid value.
 *
 * Testing invalid reqprio
 *
 * method:
 *
 *	- Create an aiocb with an invalid aio_reqprio
 *	- call aio_read with this aiocb
 */

#define _XOPEN_SOURCE 600
#include <stdio.h>
#include <sys/types.h>
#include <unistd.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
#include <aio.h>

#include "posixtest.h"

#define TNAME "aio_read/11-2.c"

int main()
{
	char tmpfname[256];
#define BUF_SIZE 111
	char buf[BUF_SIZE];
	int fd;
	struct aiocb aiocb;

#if _POSIX_ASYNCHRONOUS_IO != 200112L
	exit(PTS_UNSUPPORTED);
#endif

	snprintf(tmpfname, sizeof(tmpfname), "/tmp/pts_aio_read_11_2%d", 
		  getpid());
	unlink(tmpfname);
	fd = open(tmpfname, O_CREAT | O_RDWR | O_EXCL,
		  S_IRUSR | S_IWUSR);
	if (fd == -1)
	{
		printf(TNAME " Error at open(): %s\n",
		       strerror(errno));
		exit(PTS_UNRESOLVED);
	}

	unlink(tmpfname);

	memset(&aiocb, 0, sizeof(struct aiocb));
	aiocb.aio_fildes = fd;
	aiocb.aio_buf = buf;
	aiocb.aio_reqprio = -1;
	aiocb.aio_nbytes = BUF_SIZE;

	if (aio_read(&aiocb) != -1)
	{
		printf(TNAME " bad aio_read return value()\n");
		exit(PTS_FAIL);
	}

	if (errno != EINVAL)
	{
		printf(TNAME " errno is not EINVAL %s\n", strerror(errno));
		exit(PTS_FAIL);
	}


	close(fd);
	printf ("Test PASSED\n");
	return PTS_PASS;
}
